### Name: EB.Anova
### Title: Per Gene Group Comparison with Empirical Bayes Anova Tests
### Aliases: EB.Anova
### Keywords: models multivariate univar robust htest

### ** Examples


# The included example dataset is a simulated Affymetrix oligonucleotide
# array experiment. Type ?SimAffyDat for details.

  data(SimAffyDat)

## Not run: 
##D # If the two bioconductor packages, "affy" and "hgu95av2" are
##D # installed, replace the above line with
##D 
##D   data(SimAffyDat.ann)
##D   SimAffyDat <- SimAffyDat.ann
##D 
##D # In general if you have a replicated microarray experiment in
##D # "MyMicroArrayData" and the corresponding bioconductor annotation
##D # package is "hguFOOBAR" then, after making sure that packages
##D # "affy" and "hguFOOBAR" are installed, the enhanced functionality
##D # is turned on by adding an attribute to your dataframe as follows:
##D 
##D   attr(MyMicroArrayData, "annotation") <- "hguFOOBAR"
##D 
## End(Not run)

# Fit the Wishart/Inverse Wishart empirical Bayes model and derive per gene
# Shared Variance Hotelling T-Squared (ShHT2) statistics.

  fit.SimAffyDat <- EB.Anova(data=SimAffyDat, labels=c("log2.grp" %,% (1:2)),
                             H0="zero.means", Var.Struct = "general")

# Top 20 genes (sorted by decreasing ShHT2 statistic) and model summary

  fit.SimAffyDat

# Same screen output & opens html browser with genelist linked to GeneCards database.
# Type ?TopGenes for help

# Note:  part of the 'enhanced functionality' is floating gene names
# over the links to the gene identifiers but there is more ....
# see the help under TopGenes (well ... more on that later...)

  print(fit.SimAffyDat, browse = TRUE)

# Only the genes selected by the Benjamini-Hochberg procedure at FDR=0.05

  print(fit.SimAffyDat, FDR=0.05, allsig=TRUE)

# Just the top 35 genes

  print(fit.SimAffyDat, n.g = 35)

# In the previous two cases, supplying the argument 'browse'=TRUE produces
# the expected result. If just the genelist without the model summary is desired
# then use calls to 'TopGenes' instead of calls to 'print' in the above
# with exactly the same sytax otherwise.

# Try the update method with Var.Struct="simple":

  fitSV.SimAffyDat <- update(fit.SimAffyDat, Var.Struct = "simple")

# If for some reason, you want the 'EBfit' component then use either

  x <- fit.SimAffyDat$EBfit   # or
  x <- EBfit(fit.SimAffyDat)

# The 'EBfit' print method supplies the simple summary table of coefficients,
# standard errors and Wald statistic p-values mentioned above.

  x

# Notice that the actual structure is more detailed:

  names(x)
  x$log.likelihood
  x$variance
 
# You can perform non-assignment operations directly on the data component
# of the object using 'as.data.frame', which contains the statistics,
# unsorted in the  same order as the original dataset, using 'as.data.frame':

  as.data.frame(fit.SimAffyDat)[1:100, ]




