### Name: TopGenes
### Title: Gene lists linked to Gene Cards
### Aliases: TopGenes
### Keywords: print

### ** Examples

#  NOTE:  Full browser functionality includes (i) links to the NCI 'GENECARDS'
#  database and (ii) gene name floats above the affy identifier when mouse
#  pointer is over the link.  Right now this is specific to Affymetrix arrays
#  more functionality may be added later.  The hot-links feature, (i), works
#  provided the dataset is given affy identifiers for rownames.  These are
#  the default if you used the Bioconductor package 'affy' suite of preprocessing
#  routines.  The floating gene names on mouse-over function, (ii), works provided
#  you attach the annotation name as an attribute to your dataset.
#  For exammple, suppose you used the 'affy' suite to do pre-processing
#  and have obtained the exprSet, 'MyEset', and will use  MYDAT <- exprs(MyEset)
#  in calls to EB.Anova. Then function (i) is automatic, and to get function (ii) to
#  work requires the following simple command:
#
#  attr(MYDAT, "annotation") <- annotation(MyEset)
#
#
#
# The included example dataset is a simulated hgu95av2 Affymetrix oligonucleotide
# array experiment. Type ?SimAffyDat for details.

  data(SimAffyDat)

# Fit the Wishart/Inverse Wishart empirical Bayes model and derive per gene
# Shared Variance Hotelling T-Squared (ShHT2) statistics.

  fit.SimAffyDat <- EB.Anova(data=SimAffyDat, labels=c("log2.grp" %,% (1:2)),
                             H0="zero.means", Var.Struct = "general")

# Top 20 genes (sorted by decreasing ShHT2 statistic) and model summary

  fit.SimAffyDat

# Same screen output & opens html browser with genelist linked to GeneCards database.

  TopGenes(fit.SimAffyDat, browse = TRUE)

# Only the genes selected by the Benjamini-Hochberg procedure at FDR=0.05

  TopGenes(fit.SimAffyDat, FDR=0.05, allsig=TRUE)

# Just the top 35 genes

  TopGenes(fit.SimAffyDat, n.g = 35)

# Try the Var.Struct="simple" option:

  fitSV.SimAffyDat <- update(EBfit(fit.SimAffyDat), Var.Struct = "simple")

# Now try TopGenes using the univariate statistic:

  TopGenes(fitSV.SimAffyDat, FDR=0.05, allsig=TRUE)




